//
// C++ Interface: CSceneEdit
//
// Description: 
//
//
// Author: Harald Krippel <harald@the-develop.net>, (C) 2007
//
// Copyright: See COPYING file that comes with this distribution
//
//

#ifndef CSCENEEDITDLG_H
#define CSCENEEDITDLG_H

/**
  *@author Krippel Harald
  */

#include <QDialog>
#include <QString>
#include <QPixmap>

#include "ui_scenedlg4.h"
#include "CQcakeDlg.hpp"
#include "listviews.hpp"

class CSceneEditDlg: public CQcakeDlg
{
    Q_OBJECT
      
public:
    CSceneEditDlg(QString, QWidget * parent = 0, Qt::WFlags f = 0 );
    ~CSceneEditDlg();

public slots:
    virtual void slotGetData();
    virtual void slotGetData(FolderListItem *i);
    virtual void slotEditData();
    virtual void slotEditColor();

private slots:
 
protected:
    Ui::SceneEditDlg ui;    
    FolderListItem *point;
    QColor mycolor;
    
private:
    QWidget *myParent;
};
#endif
